@@ -26,6 +26,7 @@
 #include "css-code.h"
 #include "gcal-application.h"
 #include "gcal-debug.h"
+#include "gcal-log.h"
 #include "gcal-shell-search-provider.h"
 #include "gcal-window.h"
 
@@ -77,6 +78,7 @@ static void     gcal_application_quit                 (GSimpleAction           *
 G_DEFINE_TYPE (GcalApplication, gcal_application, GTK_TYPE_APPLICATION);
 
 static gboolean show_version = FALSE;
+static gboolean debug = FALSE;
 static gchar* date = NULL;
 static gchar* uuid = NULL;
 
@@ -86,6 +88,11 @@ static GOptionEntry gcal_application_goptions[] = {
     G_OPTION_ARG_NONE, &show_version,
     N_("Display version number"), NULL
   },
+  {
+    "debug", 'd', 0,
+    G_OPTION_ARG_NONE, &debug,
+    N_("Enable debug messages"), NULL
+  },
   {
     "date", 'd', 0,
     G_OPTION_ARG_STRING, &date,
@@ -228,7 +235,7 @@ gcal_application_activate (GApplication *application)
 
   gtk_window_present (GTK_WINDOW (self->window));
 
-  if (!self->initial_date)
+  if (self->initial_date)
     g_object_set (self->window, "active-date", self->initial_date, NULL);
 
   g_clear_pointer (&self->initial_date, g_free);
@@ -293,6 +300,9 @@ gcal_application_command_line (GApplication            *app,
       return 0;
     }
 
+  if (debug)
+    gcal_log_init ();
+
   if (uuid != NULL)
     {
       gcal_application_set_uuid (GCAL_APPLICATION (app), uuid);
