@@ -80,6 +80,7 @@ struct _GcalEvent
   GObject             parent;
 
   gchar              *uid;
+  gboolean            has_recurrence;
 
   /*
    * The description is cached in the class because it
@@ -104,7 +105,6 @@ struct _GcalEvent
   ESource            *source;
 
   gboolean            is_valid : 1;
-  gboolean            is_initialized : 1;
   GError             *initialization_error;
 };
 
@@ -126,6 +126,7 @@ enum {
   PROP_SUMMARY,
   PROP_TIMEZONE,
   PROP_UID,
+  PROP_HAS_RECURRENCE,
   N_PROPS
 };
 
@@ -364,9 +365,13 @@ gcal_event_set_component_internal (GcalEvent     *self,
       /* Setup UID */
       gcal_event_update_uid_internal (self);
 
+      /* Set has-recurrence to check if the component has recurrence or not */
+      self->has_recurrence = e_cal_component_has_recurrences(component);
+
       /* Load and setup the alarms */
       load_alarms (self);
 
+      g_object_notify (G_OBJECT (self), "has-recurrence");
       g_object_notify (G_OBJECT (self), "component");
       g_object_notify (G_OBJECT (self), "location");
       g_object_notify (G_OBJECT (self), "summary");
@@ -396,13 +401,6 @@ gcal_event_initable_init (GInitable     *initable,
 
   G_LOCK (init_lock);
 
-  if (self->is_initialized)
-    goto out;
-
-
-out:
-  self->is_initialized = TRUE;
-
   if (!self->is_valid)
     g_propagate_error (error, g_error_copy (self->initialization_error));
 
@@ -489,6 +487,10 @@ gcal_event_get_property (GObject    *object,
       g_value_set_string (value, self->uid);
       break;
 
+    case PROP_HAS_RECURRENCE:
+      g_value_set_boolean (value, self->has_recurrence);
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     }
@@ -700,6 +702,21 @@ gcal_event_class_init (GcalEventClass *klass)
                                                         "The unique identifier of the event",
                                                         "",
                                                         G_PARAM_READABLE));
+
+  /**
+  * GcalEvent::has-recurrence:
+  *
+  * The recurrence property of the event.
+  */
+  g_object_class_install_property (object_class,
+                                   PROP_HAS_RECURRENCE,
+                                   g_param_spec_boolean ("has-recurrence",
+                                                         "If event has recurrence",
+                                                         "Whether the event has recurrence or not",
+                                                         FALSE,
+                                                         G_PARAM_READABLE));
+
+
 }
 
 static void
@@ -899,7 +916,9 @@ gcal_event_set_date_end (GcalEvent *self,
 
       g_object_notify (G_OBJECT (self), "date-end");
 
-      g_clear_pointer (&component_dt, e_cal_component_free_datetime);
+      e_cal_component_free_datetime (&current);
+      e_cal_component_free_datetime (component_dt);
+      g_free (component_dt);
     }
 }
 
@@ -954,7 +973,9 @@ gcal_event_set_date_start (GcalEvent *self,
 
       g_object_notify (G_OBJECT (self), "date-start");
 
-      g_clear_pointer (&component_dt, e_cal_component_free_datetime);
+      e_cal_component_free_datetime (&current);
+      e_cal_component_free_datetime (component_dt);
+      g_free (component_dt);
     }
 }
 
@@ -1008,6 +1029,22 @@ gcal_event_set_description (GcalEvent   *self,
     }
 }
 
+/**
+ * gcal_event_has_recurrence:
+ * @self: a #GcalEvent
+ *
+ * Returns whether the event has recurrences or not.
+ *
+ * Returns: %TRUE if @self has recurrences, %FALSE otherwise
+ */
+gboolean
+gcal_event_has_recurrence (GcalEvent *self)
+{
+  g_return_val_if_fail (GCAL_IS_EVENT (self), FALSE);
+
+  return e_cal_component_has_recurrences (self->component);
+}
+
 /**
  * gcal_event_has_alarms:
  * @self: a #GcalEvent
