@@ -91,6 +91,8 @@ struct _GcalManager
 
   GoaClient       *goa_client;
 
+  GcalClock       *clock;
+
   /* state flags */
   gboolean         goa_client_ready;
   gint             sources_at_launch;
@@ -107,6 +109,7 @@ G_DEFINE_TYPE (GcalManager, gcal_manager, G_TYPE_OBJECT)
 enum
 {
   PROP_0,
+  PROP_CLOCK,
   PROP_DEFAULT_CALENDAR,
   PROP_LOADING,
   PROP_SETTINGS,
@@ -377,6 +380,8 @@ on_client_connected (GObject      *source_object,
       return;
     }
 
+  g_object_set_data (G_OBJECT (source), "client", client);
+
   unit = g_new0 (GcalManagerUnit, 1);
   unit->connected = TRUE;
   unit->client = g_object_ref (client);
@@ -899,6 +904,7 @@ gcal_manager_finalize (GObject *object)
 
   GCAL_ENTRY;
 
+  g_clear_object (&manager->clock);
   g_clear_object (&manager->settings);
   g_clear_object (&manager->goa_client);
   g_clear_object (&manager->e_data_model);
@@ -999,6 +1005,17 @@ gcal_manager_class_init (GcalManagerClass *klass)
   object_class->set_property = gcal_manager_set_property;
   object_class->get_property = gcal_manager_get_property;
 
+  /**
+   * GcalManager:clock:
+   *
+   * The internal clock of Calendar.
+   */
+  properties[PROP_CLOCK] = g_param_spec_object ("clock",
+                                                "Clock",
+                                                "The internal clock of Calendar",
+                                                GCAL_TYPE_CLOCK,
+                                                G_PARAM_READWRITE);
+
   /**
    * GcalManager:default-calendar:
    *
@@ -1081,7 +1098,7 @@ gcal_manager_class_init (GcalManagerClass *klass)
 static void
 gcal_manager_init (GcalManager *self)
 {
-  ;
+  self->clock = gcal_clock_new ();
 }
 
 /* Public API */
@@ -1144,8 +1161,6 @@ gcal_manager_get_sources (GcalManager *manager)
 
   while (g_hash_table_iter_next (&iter, &key, &value))
     {
-      GcalManagerUnit *unit = value;
-
       if (!is_source_enabled (key))
         continue;
 
@@ -1562,7 +1577,6 @@ gcal_manager_disable_source (GcalManager *manager,
                              ESource     *source)
 {
   ESourceSelectable *selectable;
-  GcalManagerUnit *unit;
   const gchar *source_uid;
 
   GCAL_ENTRY;
@@ -1570,7 +1584,6 @@ gcal_manager_disable_source (GcalManager *manager,
   g_return_if_fail (GCAL_IS_MANAGER (manager));
   g_return_if_fail (E_IS_SOURCE (source));
 
-  unit = g_hash_table_lookup (manager->clients, source);
   selectable = e_source_get_extension (source, E_SOURCE_EXTENSION_CALENDAR);
 
   if (!is_source_enabled (source))
@@ -1737,12 +1750,14 @@ gcal_manager_create_event (GcalManager *manager,
  * gcal_manager_update_event:
  * @manager: a #GcalManager
  * @event: a #GcalEvent
+ * @mod: an #ECalObjModType
  *
  * Saves all changes made to @event persistently.
  */
 void
-gcal_manager_update_event (GcalManager *manager,
-                           GcalEvent   *event)
+gcal_manager_update_event (GcalManager    *manager,
+                           GcalEvent      *event,
+                           ECalObjModType  mod)
 {
   GcalManagerUnit *unit;
   ECalComponent *component;
@@ -1755,6 +1770,15 @@ gcal_manager_update_event (GcalManager *manager,
   unit = g_hash_table_lookup (manager->clients, gcal_event_get_source (event));
   component = gcal_event_get_component (event);
 
+  /*
+   * HACK: In Evolution Calendar, a NULL 'rid' is usually associated
+   * with an E_CAL_OBJ_MOD_ALL modtype. Here, we are manually setting
+   * the rid to NULL when modifying a recurrent event with MOD_ALL
+   * modtype.
+   */
+  if (mod == E_CAL_OBJ_MOD_ALL)
+    e_cal_component_set_recurid (component, NULL);
+
   /*
    * While we're updating the event, we don't want the component
    * to be destroyed, so take a reference of the component while
@@ -1764,7 +1788,7 @@ gcal_manager_update_event (GcalManager *manager,
 
   e_cal_client_modify_object (unit->client,
                               e_cal_component_get_icalcomponent (component),
-                              E_CAL_OBJ_MOD_THIS,
+                              mod,
                               NULL,
                               on_event_updated,
                               component);
@@ -1776,16 +1800,19 @@ gcal_manager_update_event (GcalManager *manager,
  * gcal_manager_remove_event:
  * @manager: a #GcalManager
  * @event: a #GcalEvent
+ * @mod: an #ECalObjModType
  *
  * Deletes @event.
  */
 void
-gcal_manager_remove_event (GcalManager *manager,
-                           GcalEvent   *event)
+gcal_manager_remove_event (GcalManager    *manager,
+                           GcalEvent      *event,
+                           ECalObjModType  mod)
 {
   GcalManagerUnit *unit;
-  ECalComponentId *id;
   ECalComponent *component;
+  gchar *rid;
+  const gchar *uid;
 
   GCAL_ENTRY;
 
@@ -1794,7 +1821,12 @@ gcal_manager_remove_event (GcalManager *manager,
 
   component = gcal_event_get_component (event);
   unit = g_hash_table_lookup (manager->clients, gcal_event_get_source (event));
-  id = e_cal_component_get_id (component);
+  rid = NULL;
+
+  e_cal_component_get_uid (component, &uid);
+
+  if (gcal_event_has_recurrence (event))
+    rid = e_cal_component_get_recurid_as_string (component);
 
   /*
    * While we're removing the event, we don't want the component
@@ -1804,14 +1836,14 @@ gcal_manager_remove_event (GcalManager *manager,
   g_object_ref (component);
 
   e_cal_client_remove_object (unit->client,
-                              id->uid,
-                              id->rid,
-                              E_CAL_OBJ_MOD_THIS,
+                              uid,
+                              mod == E_CAL_OBJ_MOD_ALL ? NULL : rid,
+                              mod,
                               manager->async_ops,
                               on_event_removed,
                               component);
 
-  e_cal_component_free_id (id);
+  g_free (rid);
 
   GCAL_EXIT;
 }
@@ -1950,6 +1982,22 @@ gcal_manager_get_loading (GcalManager *self)
   return !self->goa_client_ready || self->sources_at_launch > 0;
 }
 
+/**
+ * gcal_manager_get_clock:
+ * @self: a #GcalManager
+ *
+ * Retrieves the internal #GcalClock of @self.
+ *
+ * Returns: (transfer none): a #GcalClock.
+ */
+GcalClock*
+gcal_manager_get_clock (GcalManager *self)
+{
+  g_return_val_if_fail (GCAL_IS_MANAGER (self), NULL);
+
+  return self->clock;
+}
+
 /**
  * gcal_manager_get_event_from_shell_search:
  * @manager: a #GcalManager
