@@ -150,6 +150,7 @@ struct _GcalWindow
   NewEventData        *event_creation_data;
 
   GcalEvent           *event_to_delete;
+  ECalObjModType       event_to_delete_mod;
 
   /* calendar management */
   GtkWidget           *calendar_popover;
@@ -159,10 +160,13 @@ struct _GcalWindow
   gint                 refresh_timeout;
   gint                 refresh_timeout_id;
   gint                 open_edit_dialog_timeout_id;
-  gint                 update_current_date_timeout_id;
 
   /* temp to keep event_creation */
   gboolean             open_edit_dialog;
+
+  /* handler for the searh_view */
+  gint                 click_outside_handler_id;
+
 };
 
 enum
@@ -209,6 +213,27 @@ static const GActionEntry actions[] = {
 /*
  * Auxiliary methods
  */
+
+static gboolean
+hide_search_view_on_click_outside (GcalWindow     *window,
+                                   GdkEventButton *event,
+                                   GtkPopover     *popover)
+{
+  GdkWindow *search_view_window;
+
+  search_view_window = gtk_widget_get_window (GTK_WIDGET (popover)); 
+
+  /* If the event is not produced in the search view widget, we hide the search_bar */
+  if (event->window != search_view_window) 
+    {
+      gtk_popover_popdown (popover);
+      gtk_search_bar_set_search_mode (GTK_SEARCH_BAR (window->search_bar), FALSE);
+    }
+
+  return GDK_EVENT_PROPAGATE;
+}
+
+
 static void
 update_today_button_sensitive (GcalWindow *window)
 {
@@ -271,6 +296,8 @@ update_active_date (GcalWindow   *window,
   previous_date = window->active_date;
   window->active_date = new_date;
 
+  g_debug ("Updating active date to %s", icaltime_as_ical_string (*new_date));
+
   gcal_view_set_date (GCAL_VIEW (window->views[GCAL_WINDOW_VIEW_WEEK]), new_date);
   gcal_view_set_date (GCAL_VIEW (window->views[GCAL_WINDOW_VIEW_MONTH]), new_date);
   gcal_view_set_date (GCAL_VIEW (window->views[GCAL_WINDOW_VIEW_YEAR]), new_date);
@@ -467,21 +494,6 @@ key_pressed (GtkWidget *widget,
                                       event);
 }
 
-static gboolean
-update_current_date (GcalWindow *self)
-{
-  GCAL_ENTRY;
-
-  if (self->update_current_date_timeout_id == 0)
-    self->update_current_date_timeout_id = g_timeout_add_seconds (60, (GSourceFunc) update_current_date, self);
-
-  gtk_widget_queue_draw (self->views[GCAL_WINDOW_VIEW_WEEK]);
-  gtk_widget_queue_draw (self->views[GCAL_WINDOW_VIEW_MONTH]);
-  gtk_widget_queue_draw (self->views[GCAL_WINDOW_VIEW_YEAR]);
-
-  GCAL_RETURN (G_SOURCE_CONTINUE);
-}
-
 static void
 search_event_selected (GcalSearchView *search_view,
                        icaltimetype   *date,
@@ -1074,6 +1086,8 @@ edit_dialog_closed (GtkDialog *dialog,
   GcalEvent *event;
   GcalView *view;
   GList *widgets;
+  ECalObjModType mod;
+  ESource *source;
 
   GCAL_ENTRY;
 
@@ -1081,8 +1095,17 @@ edit_dialog_closed (GtkDialog *dialog,
   edit_dialog = GCAL_EDIT_DIALOG (dialog);
   event = gcal_edit_dialog_get_event (edit_dialog);
   view = GCAL_VIEW (window->views[window->active_view]);
+  mod = E_CAL_OBJ_MOD_THIS;
+  source = gcal_event_get_source (event);
 
-  gtk_widget_hide (GTK_WIDGET (dialog));
+  if (response != GCAL_RESPONSE_CREATE_EVENT &&
+      response != GTK_RESPONSE_CANCEL &&
+      response != GTK_RESPONSE_DELETE_EVENT &&
+      gcal_event_has_recurrence (event) &&
+      !ask_recurrence_modification_type (GTK_WIDGET (dialog), &mod, source))
+    {
+      return;
+    }
 
   switch (response)
     {
@@ -1091,13 +1114,13 @@ edit_dialog_closed (GtkDialog *dialog,
       break;
 
     case GCAL_RESPONSE_SAVE_EVENT:
-      gcal_manager_update_event (window->manager, event);
+      gcal_manager_update_event (window->manager, event, mod);
       break;
 
     case GCAL_RESPONSE_DELETE_EVENT:
       if (window->event_to_delete != NULL)
         {
-          gcal_manager_remove_event (window->manager, window->event_to_delete);
+          gcal_manager_remove_event (window->manager, window->event_to_delete, window->event_to_delete_mod);
           g_clear_object (&window->event_to_delete);
 
           create_notification (GCAL_WINDOW (user_data), _("Another event deleted"), _("Undo"));
@@ -1116,6 +1139,8 @@ edit_dialog_closed (GtkDialog *dialog,
 
       g_set_object (&window->event_to_delete, event);
 
+      window->event_to_delete_mod = mod;
+
       /* hide widget of the event */
       widgets = gcal_view_get_children_by_uuid (view, gcal_event_get_uid (event));
 
@@ -1129,6 +1154,8 @@ edit_dialog_closed (GtkDialog *dialog,
 
     }
 
+  gtk_widget_hide (GTK_WIDGET (dialog));
+
   gcal_edit_dialog_set_event (edit_dialog, NULL);
 
   GCAL_EXIT;
@@ -1143,7 +1170,21 @@ search_toggled (GObject    *object,
 
   /* update header_bar widget */
   if (gtk_search_bar_get_search_mode (GTK_SEARCH_BAR (window->search_bar)))
-    gcal_search_view_search (GCAL_SEARCH_VIEW (window->search_view), NULL, NULL);
+    {
+      gcal_search_view_search (GCAL_SEARCH_VIEW (window->search_view), NULL, NULL);
+
+      /* When the search button is toogled we connect the signal */
+      window->click_outside_handler_id = g_signal_connect (window,
+                                                           "button-press-event",
+                                                           G_CALLBACK (hide_search_view_on_click_outside),
+                                                           window->search_view);
+    }
+  else
+    {
+      /* When the search mode is false we disconnect the handler */
+      g_signal_handler_disconnect (window, window->click_outside_handler_id);
+    }
+
 }
 
 static void
@@ -1184,7 +1225,7 @@ remove_event (GtkWidget  *notification,
 
   if (window->event_to_delete != NULL)
     {
-      gcal_manager_remove_event (window->manager, window->event_to_delete);
+      gcal_manager_remove_event (window->manager, window->event_to_delete, window->event_to_delete_mod);
       g_clear_object (&window->event_to_delete);
     }
 }
@@ -1254,16 +1295,16 @@ gcal_window_finalize (GObject *object)
       window->open_edit_dialog_timeout_id = 0;
     }
 
-  if (window->update_current_date_timeout_id > 0)
+  if (window->refresh_timeout_id > 0)
     {
-      g_source_remove (window->update_current_date_timeout_id);
-      window->update_current_date_timeout_id = 0;
+      g_source_remove (window->refresh_timeout_id);
+      window->refresh_timeout_id = 0;
     }
 
   /* If we have a queued event to delete, remove it now */
   if (window->event_to_delete)
     {
-      gcal_manager_remove_event (window->manager, window->event_to_delete);
+      gcal_manager_remove_event (window->manager, window->event_to_delete, window->event_to_delete_mod);
       g_clear_object (&window->event_to_delete);
     }
 
@@ -1302,12 +1343,15 @@ gcal_window_set_property (GObject      *object,
       gtk_stack_set_visible_child (GTK_STACK (self->views_stack),
                                    self->views[self->active_view]);
       return;
+
     case PROP_ACTIVE_DATE:
       update_active_date (GCAL_WINDOW (object), g_value_dup_boxed (value));
       return;
+
     case PROP_NEW_EVENT_MODE:
       set_new_event_mode (GCAL_WINDOW (object), g_value_get_boolean (value));
       return;
+
     case PROP_MANAGER:
       if (g_set_object (&self->manager, g_value_get_object (value)))
         {
@@ -1335,6 +1379,7 @@ gcal_window_set_property (GObject      *object,
           gcal_year_view_set_manager (GCAL_YEAR_VIEW (self->year_view), self->manager);
           gcal_quick_add_popover_set_manager (GCAL_QUICK_ADD_POPOVER (self->quick_add_popover), self->manager);
           gcal_source_dialog_set_manager (GCAL_SOURCE_DIALOG (self->source_dialog), self->manager);
+          gcal_search_view_connect (GCAL_SEARCH_VIEW (self->search_view), self->manager);
 
           g_object_notify (object, "manager");
         }
@@ -1360,12 +1405,15 @@ gcal_window_get_property (GObject    *object,
     case PROP_ACTIVE_VIEW:
       g_value_set_enum (value, self->active_view);
       return;
+
     case PROP_MANAGER:
       g_value_set_object (value, self->manager);
       return;
+
     case PROP_ACTIVE_DATE:
       g_value_set_boxed (value, self->active_date);
       return;
+
     case PROP_NEW_EVENT_MODE:
       g_value_set_boolean (value, self->new_event_mode);
       return;
@@ -1591,7 +1639,6 @@ gcal_window_init (GcalWindow *self)
   gcal_year_view_set_use_24h_format (GCAL_YEAR_VIEW (self->views[GCAL_WINDOW_VIEW_YEAR]), use_24h_format);
 
   /* search view */
-  gcal_search_view_connect (GCAL_SEARCH_VIEW (self->search_view), self->manager);
   gcal_search_view_set_time_format (GCAL_SEARCH_VIEW (self->search_view), use_24h_format);
 
   /* refresh timeout, first is fast */
@@ -1618,8 +1665,6 @@ gcal_window_init (GcalWindow *self)
   gcal_window_add_accelerator (app, "win.change-view(1)",  "<Ctrl>1")
   gcal_window_add_accelerator (app, "win.change-view(2)",  "<Ctrl>2");
   gcal_window_add_accelerator (app, "win.change-view(3)",  "<Ctrl>3");
-
-  update_current_date (self);
 }
 
 /* Public API */
