@@ -199,7 +199,7 @@ get_cell_position (GcalMonthView *self,
 }
 static void
 rebuild_popover_for_day (GcalMonthView *self,
-                         gint           day)
+                         GDateTime     *day)
 {
   GcalSubscriberViewPrivate *ppriv;
   GList *l;
@@ -222,7 +222,7 @@ rebuild_popover_for_day (GcalMonthView *self,
 
   ppriv = GCAL_SUBSCRIBER_VIEW (self)->priv;
 
-  label_title = g_strdup_printf ("%s %d", gcal_get_month_name (self->date->month - 1), day);
+  label_title = g_date_time_format (day, _("%B %d"));
   gtk_label_set_text (GTK_LABEL (self->popover_title), label_title);
   g_free (label_title);
 
@@ -254,7 +254,7 @@ rebuild_popover_for_day (GcalMonthView *self,
           dt_start = g_date_time_new (tz,
                                       g_date_time_get_year (current_date),
                                       g_date_time_get_month (current_date),
-                                      day,
+                                      g_date_time_get_day_of_month (day),
                                       0, 0, 0);
 
           dt_end = g_date_time_add_days (dt_start, 1);
@@ -320,7 +320,9 @@ rebuild_popover_for_day (GcalMonthView *self,
   child_widget = gtk_bin_get_child (GTK_BIN (self->overflow_popover));
   gtk_widget_set_size_request (child_widget, 200, -1);
 
-  g_object_set_data (G_OBJECT (self->overflow_popover), "selected-day", GINT_TO_POINTER (day));
+  g_object_set_data (G_OBJECT (self->overflow_popover),
+                     "selected-day",
+                     GINT_TO_POINTER (g_date_time_get_day_of_month (day)));
 }
 
 static gboolean
@@ -347,7 +349,7 @@ show_popover_for_position (GcalMonthView *self,
     {
       self->hovered_overflow_indicator = self->pressed_overflow_indicator;
 
-      rebuild_popover_for_day (GCAL_MONTH_VIEW (widget), g_date_time_get_day_of_month (end_dt));
+      rebuild_popover_for_day (GCAL_MONTH_VIEW (widget), end_dt);
       gtk_widget_show_all (self->overflow_popover);
 
       gtk_widget_queue_draw (widget);
@@ -487,9 +489,13 @@ get_widget_parts (gint     first_cell,
                   GArray  *cells,
                   GArray  *lengths)
 {
-  gint i;
+  gdouble old_y;
+  gdouble y;
   gint current_part_length;
-  gdouble y, old_y = - 1.0;
+  gint i;
+
+  old_y  = -1.0;
+  current_part_length = 0;
 
   if (last_cell < first_cell)
     {
@@ -501,24 +507,21 @@ get_widget_parts (gint     first_cell,
   for (i = first_cell; i <= last_cell; i++)
     {
       if (size_left[i] < natural_height)
+        return FALSE;
+
+      y = vertical_cell_space - size_left[i];
+
+      if (old_y == -1.0 || y != old_y)
         {
-          return FALSE;
+          current_part_length = 1;
+          g_array_append_val (cells, i);
+          g_array_append_val (lengths, current_part_length);
+          old_y = y;
         }
       else
         {
-          y = vertical_cell_space - size_left[i];
-          if (y != old_y)
-            {
-              current_part_length = 1;
-              g_array_append_val (cells, i);
-              g_array_append_val (lengths, current_part_length);
-              old_y = y;
-            }
-          else
-            {
-              current_part_length++;
-              g_array_index (lengths, gint, lengths->len - 1) = current_part_length;
-            }
+          current_part_length++;
+          g_array_index (lengths, gint, lengths->len - 1) = current_part_length;
         }
     }
 
@@ -775,6 +778,8 @@ gcal_month_view_drag_drop (GtkWidget      *widget,
   GtkWidget *event_widget;
   GDateTime *start_dt, *end_dt, *current_dt;
   GcalEvent *event;
+  ECalObjModType mod;
+  ESource *source;
   gint cell, diff;
   gint start_month, current_month;
   gint start_year, current_year;
@@ -782,11 +787,19 @@ gcal_month_view_drag_drop (GtkWidget      *widget,
 
   cell = get_dnd_cell (widget, x, y);
   event_widget = gtk_drag_get_source_widget (context);
+  mod = E_CAL_OBJ_MOD_THIS;
 
   if (!GCAL_IS_EVENT_WIDGET (event_widget))
     return FALSE;
 
   event = gcal_event_widget_get_event (GCAL_EVENT_WIDGET (event_widget));
+  source = gcal_event_get_source (event);
+
+  if (gcal_event_has_recurrence (event) &&
+      !ask_recurrence_modification_type (widget, &mod, source))
+    {
+      goto out;
+    }
 
   /* Move the event's date */
   start_dt = gcal_event_get_date_start (event);
@@ -828,7 +841,7 @@ gcal_month_view_drag_drop (GtkWidget      *widget,
           g_clear_pointer (&new_end, g_date_time_unref);
         }
 
-      gcal_manager_update_event (self->manager, event);
+      gcal_manager_update_event (self->manager, event, mod);
 
       g_clear_pointer (&new_start, g_date_time_unref);
 
@@ -837,6 +850,7 @@ gcal_month_view_drag_drop (GtkWidget      *widget,
 
   g_clear_pointer (&start_dt, g_date_time_unref);
 
+out:
   /* Cancel the DnD */
   self->dnd_cell = -1;
   gtk_drag_unhighlight (widget);
@@ -1624,56 +1638,6 @@ gcal_month_view_draw (GtkWidget *widget,
 
       nr_day = g_strdup_printf ("%d", j);
 
-      if (g_hash_table_contains (ppriv->overflow_cells, GINT_TO_POINTER (real_i)))
-        {
-          GList *l;
-          PangoLayout *overflow_layout;
-          PangoFontDescription *ofont_desc;
-          gchar *overflow_str;
-          gdouble y_value;
-
-          l = g_hash_table_lookup (ppriv->overflow_cells, GINT_TO_POINTER (real_i));
-
-          /* TODO: Warning: in some languages this string can be too long and may overlap with the number */
-          overflow_str = g_strdup_printf (g_dngettext (GETTEXT_PACKAGE, "Other event", "Other %d events", g_list_length (l)),
-                                          g_list_length (l));
-
-          gtk_style_context_save (context);
-          gtk_style_context_add_class (context, "overflow");
-          if (self->hovered_overflow_indicator == real_i)
-            {
-              gtk_style_context_set_state (context, GTK_STATE_FLAG_PRELIGHT);
-              gtk_style_context_get (context, GTK_STATE_FLAG_PRELIGHT, "font", &ofont_desc, NULL);
-            }
-          else
-            {
-              gtk_style_context_get (context, state, "font", &ofont_desc, NULL);
-            }
-
-          overflow_layout = gtk_widget_create_pango_layout (widget, overflow_str);
-
-          pango_layout_set_font_description (overflow_layout, ofont_desc);
-          pango_layout_set_width (overflow_layout, pango_units_from_double (cell_width));
-          pango_layout_set_alignment (overflow_layout, PANGO_ALIGN_CENTER);
-          pango_layout_get_pixel_size (overflow_layout, &font_width, &font_height);
-          y_value = cell_height * (row + 1 + first_row_gap) - font_height - padding.bottom + start_grid_y;
-
-          if ((!gtk_widget_is_visible (self->overflow_popover) && self->hovered_overflow_indicator == real_i) ||
-               gtk_widget_is_visible (self->overflow_popover))
-            {
-              gtk_render_background (context, cr, cell_width * column, y_value - padding.bottom,
-                                     cell_width, font_height + padding.bottom * 2);
-            }
-
-          gtk_render_layout (context, cr, cell_width * column, y_value, overflow_layout);
-
-          gtk_style_context_remove_class (context, "overflow");
-          gtk_style_context_restore (context);
-          g_free (overflow_str);
-          pango_font_description_free (ofont_desc);
-          g_object_unref (overflow_layout);
-        }
-
       if (self->date->year == g_date_time_get_year (today) &&
           self->date->month == g_date_time_get_month (today) &&
           j == g_date_time_get_day_of_month (today))
@@ -1740,6 +1704,57 @@ gcal_month_view_draw (GtkWidget *widget,
         }
 
       g_free (nr_day);
+
+      if (g_hash_table_contains (ppriv->overflow_cells, GINT_TO_POINTER (real_i)))
+        {
+          GList *l;
+          PangoLayout *overflow_layout;
+          PangoFontDescription *ofont_desc;
+          gchar *overflow_str;
+          gdouble y_value;
+
+          l = g_hash_table_lookup (ppriv->overflow_cells, GINT_TO_POINTER (real_i));
+
+          /* TODO: Warning: in some languages this string can be too long and may overlap with the number */
+          overflow_str = g_strdup_printf (g_dngettext (GETTEXT_PACKAGE, "Other event", "Other %d events", g_list_length (l)),
+                                          g_list_length (l));
+
+          gtk_style_context_save (context);
+          gtk_style_context_add_class (context, "overflow");
+          if (self->hovered_overflow_indicator == real_i)
+            {
+              gtk_style_context_set_state (context, GTK_STATE_FLAG_PRELIGHT);
+              gtk_style_context_get (context, GTK_STATE_FLAG_PRELIGHT, "font", &ofont_desc, NULL);
+            }
+          else
+            {
+              gtk_style_context_get (context, state, "font", &ofont_desc, NULL);
+            }
+
+          overflow_layout = gtk_widget_create_pango_layout (widget, overflow_str);
+
+          pango_layout_set_font_description (overflow_layout, ofont_desc);
+          pango_layout_set_width (overflow_layout, pango_units_from_double (cell_width - (font_width + padding.right + padding.left)));
+          pango_layout_set_alignment (overflow_layout, PANGO_ALIGN_CENTER);
+          pango_layout_set_ellipsize (overflow_layout, PANGO_ELLIPSIZE_END);
+          pango_layout_get_pixel_size (overflow_layout, &font_width, &font_height);
+          y_value = cell_height * (row + 1 + first_row_gap) - font_height - padding.bottom + start_grid_y;
+
+          if ((!gtk_widget_is_visible (self->overflow_popover) && self->hovered_overflow_indicator == real_i) ||
+               gtk_widget_is_visible (self->overflow_popover))
+            {
+              gtk_render_background (context, cr, cell_width * column, y_value - padding.bottom,
+                                     cell_width, font_height + padding.bottom * 2);
+            }
+
+          gtk_render_layout (context, cr, cell_width * column + padding.left, y_value, overflow_layout);
+
+          gtk_style_context_remove_class (context, "overflow");
+          gtk_style_context_restore (context);
+          g_free (overflow_str);
+          pango_font_description_free (ofont_desc);
+          g_object_unref (overflow_layout);
+        }
     }
   pango_font_description_free (sfont_desc);
   pango_font_description_free (font_desc);
@@ -1972,7 +1987,7 @@ gcal_month_view_button_press (GtkWidget      *widget,
   if (pressed_indicator && g_hash_table_contains (ppriv->overflow_cells, GINT_TO_POINTER (clicked_cell)))
     self->pressed_overflow_indicator = clicked_cell;
 
-  return TRUE;
+  return GDK_EVENT_PROPAGATE;
 }
 
 /**
@@ -2306,4 +2321,9 @@ gcal_month_view_set_manager (GcalMonthView *self,
   g_return_if_fail (GCAL_IS_MONTH_VIEW (self));
 
   self->manager = manager;
+
+  g_signal_connect_swapped (gcal_manager_get_clock (manager),
+                            "day-changed",
+                            G_CALLBACK (gtk_widget_queue_draw),
+                            self);
 }
