@@ -59,7 +59,6 @@ struct _GcalWeekGrid
   GcalRangeTree      *events;
 
   gboolean            children_changed;
-  gint                redraw_timeout_id;
 
   /*
    * These fields are "cells" rather than minutes. Each cell
@@ -250,12 +249,6 @@ gcal_week_grid_finalize (GObject *object)
   g_clear_pointer (&self->events, gcal_range_tree_unref);
   g_clear_pointer (&self->active_date, g_free);
 
-  if (self->redraw_timeout_id > 0)
-    {
-      g_source_remove (self->redraw_timeout_id);
-      self->redraw_timeout_id = 0;
-    }
-
   G_OBJECT_CLASS (gcal_week_grid_parent_class)->finalize (object);
 }
 
@@ -418,14 +411,6 @@ get_today_column (GcalWeekGrid *self)
   return days_diff;
 }
 
-static gboolean
-on_redraw_timeout_cb (gpointer data)
-{
-  gtk_widget_queue_draw (data);
-
-  return G_SOURCE_CONTINUE;
-}
-
 static gboolean
 gcal_week_grid_draw (GtkWidget *widget,
                      cairo_t   *cr)
@@ -588,14 +573,6 @@ gcal_week_grid_draw (GtkWidget *widget,
       gtk_style_context_restore (context);
     }
 
-  /* Fire the redraw timeout if needed */
-  if (self->redraw_timeout_id == 0)
-    {
-      self->redraw_timeout_id = g_timeout_add_seconds (5,
-                                                       on_redraw_timeout_cb,
-                                                       self);
-    }
-
   return FALSE;
 }
 
@@ -798,7 +775,7 @@ gcal_week_grid_button_press (GtkWidget      *widget,
 
   gtk_widget_queue_draw (widget);
 
-  return GDK_EVENT_STOP;
+  return GDK_EVENT_PROPAGATE;
 }
 
 static gboolean
@@ -979,7 +956,9 @@ gcal_week_grid_drag_drop (GtkWidget      *widget,
   g_autoptr (GDateTime) dnd_date;
   g_autoptr (GDateTime) new_end;
   GtkWidget *event_widget;
+  ECalObjModType mod;
   GcalEvent *event;
+  ESource *source;
   GTimeSpan timespan = 0;
   gboolean ltr;
   gint drop_cell;
@@ -989,7 +968,10 @@ gcal_week_grid_drag_drop (GtkWidget      *widget,
   drop_cell = get_dnd_cell (widget, x, y);
   event_widget = gtk_drag_get_source_widget (context);
 
-  week_start = dnd_date = NULL;
+  mod = E_CAL_OBJ_MOD_THIS;
+  week_start = NULL;
+  dnd_date = NULL;
+  new_end = NULL;
 
   if (!GCAL_IS_EVENT_WIDGET (event_widget))
     return FALSE;
@@ -1006,6 +988,14 @@ gcal_week_grid_drag_drop (GtkWidget      *widget,
     }
 
   event = gcal_event_widget_get_event (GCAL_EVENT_WIDGET (event_widget));
+  source = gcal_event_get_source (event);
+
+  if (gcal_event_has_recurrence (event) &&
+      !ask_recurrence_modification_type (widget, &mod, source))
+    {
+      goto out;
+    }
+
   week_start = get_start_of_week (self->active_date);
   dnd_date = g_date_time_add_minutes (week_start, drop_cell * 30);
 
@@ -1028,8 +1018,10 @@ gcal_week_grid_drag_drop (GtkWidget      *widget,
   gcal_event_set_date_end (event, new_end);
 
   /* Commit the changes */
-  gcal_manager_update_event (self->manager, event);
 
+  gcal_manager_update_event (self->manager, event, mod);
+
+out:
   /* Cancel the DnD */
   self->dnd_cell = -1;
   gtk_drag_unhighlight (widget);
@@ -1122,6 +1114,11 @@ gcal_week_grid_set_manager (GcalWeekGrid *self,
   g_return_if_fail (GCAL_IS_WEEK_GRID (self));
 
   self->manager = manager;
+
+  g_signal_connect_swapped (gcal_manager_get_clock (manager),
+                            "minute-changed",
+                            G_CALLBACK (gtk_widget_queue_draw),
+                            self);
 }
 
 void
