@@ -276,10 +276,19 @@ update_no_events_page (GcalYearView *year_view)
     }
   else
     {
-      title = g_strdup_printf ("%s %d%s",
-                               gcal_get_month_name (year_view->start_selected_date->month - 1),
-                               year_view->start_selected_date->day,
-                               has_range ? "…" : "");
+      if (has_range)
+        {
+          /* Translators: This is a date format in the sidebar of the year
+           * view when the selection starts at the specified day and the
+           * end is unspecified.  */
+          title = g_date_time_format (start_selected_date, _("%B %d…"));
+        }
+      else
+        {
+          /* Translators: This is a date format in the sidebar of the year
+           * view when there is only one specified day selected.  */
+          title = g_date_time_format (start_selected_date, _("%B %d"));
+        }
     }
 
   gtk_label_set_text (GTK_LABEL (year_view->no_events_title), title);
@@ -499,7 +508,8 @@ update_sidebar_headers (GtkListBoxRow *row,
       if (datetime_compare_date (dt, now) == 0)
         label_str = g_strdup (_("Today"));
       else
-        label_str = g_strdup_printf ("%s %d", gcal_get_month_name (date.month  - 1), date.day);
+        /* Translators: This is a date format in the sidebar of the year view. */
+        label_str = g_date_time_format (dt, _("%B %d"));
 
       label = gtk_label_new (label_str);
       gtk_style_context_add_class (gtk_widget_get_style_context (label), "sidebar-header");
@@ -1135,7 +1145,7 @@ navigator_button_press_cb (GcalYearView   *year_view,
   gboolean is_title = FALSE;
 
   if (!calculate_day_month_for_coord (year_view, event->x, event->y, &day, &month, &is_title))
-    return FALSE;
+    return GDK_EVENT_PROPAGATE;
 
   if (is_title)
     day = 1;
@@ -1144,7 +1154,7 @@ navigator_button_press_cb (GcalYearView   *year_view,
   year_view->selected_data->start_day = day;
   year_view->selected_data->start_month = month;
 
-  return TRUE;
+  return GDK_EVENT_PROPAGATE;
 }
 
 static gboolean
@@ -1478,12 +1488,23 @@ navigator_drag_drop_cb (GcalYearView   *self,
       if (!is_title)
         {
           GcalEventWidget *event_widget;
+          ECalObjModType mod;
           GcalEvent *event;
           GDateTime *start_dt, *end_dt;
           GDateTime *drop_date;
+          ESource *source;
 
           event_widget = GCAL_EVENT_WIDGET (gtk_drag_get_source_widget (context));
           event = gcal_event_widget_get_event (event_widget);
+          source = gcal_event_get_source (event);
+          mod = E_CAL_OBJ_MOD_THIS;
+
+          if (gcal_event_has_recurrence (event) &&
+              !ask_recurrence_modification_type (GTK_WIDGET (self), &mod, source))
+            {
+              goto out;
+            }
+
           start_dt = gcal_event_get_date_start (event);
           end_dt = gcal_event_get_date_end (event);
 
@@ -1512,7 +1533,7 @@ navigator_drag_drop_cb (GcalYearView   *self,
                   g_clear_pointer (&new_end, g_date_time_unref);
                 }
 
-              gcal_manager_update_event (self->manager, event);
+              gcal_manager_update_event (self->manager, event, mod);
 
               g_clear_pointer (&new_start, g_date_time_unref);
             }
@@ -1521,6 +1542,7 @@ navigator_drag_drop_cb (GcalYearView   *self,
         }
     }
 
+out:
   /* Cancel the DnD after the event is dropped */
   self->selected_data->dnd_day = -1;
   self->selected_data->dnd_month = -1;
@@ -1785,7 +1807,6 @@ gcal_year_view_component_added (ECalDataModelSubscriber *subscriber,
   GDateTime *event_start, *event_end;
   GcalEvent *event;
   GError *error;
-  GList *l;
   guint i, start_month, end_month;
 
   error = NULL;
@@ -2035,6 +2056,11 @@ gcal_year_view_set_manager (GcalYearView *year_view,
                             GcalManager  *manager)
 {
   year_view->manager = manager;
+
+  g_signal_connect_swapped (gcal_manager_get_clock (manager),
+                            "day-changed",
+                            G_CALLBACK (gtk_widget_queue_draw),
+                            year_view->navigator);
 }
 
 void
